==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDetailDescription } from "./WebColumnMovingEndEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDetailDescriptionMetadata.c(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
            a.item("Target", "ExportedType:WebColumn");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebColumnMovingEndEventArgsDetail", () => new WebColumnMovingEndEventArgsDetailDescription());
            a.ac("WebColumnMovingEndEventArgsDetail", WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEndEventArgsDetailDescriptionMetadata, 'WebColumnMovingEndEventArgsDetailDescriptionMetadata');
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebColumnMovingEndEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEndEventArgsDetailDescription } from "./WebColumnMovingEndEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnMovingEndEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnMovingEndEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnMovingEndEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnMovingEndEventArgsDetailDescriptionMetadata.c(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnMovingEndEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Source", "ExportedType:WebColumn");
            a.item("Target", "ExportedType:WebColumn");
            a.item("Cancel", "Boolean");
        }
        static d(a) {
            WebColumnMovingEndEventArgsDetailDescriptionMetadata.b(a);
            a.ae("WebColumnMovingEndEventArgsDetail", () => new WebColumnMovingEndEventArgsDetailDescription());
            a.ad("WebColumnMovingEndEventArgsDetail", WebColumnMovingEndEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnMovingEndEventArgsDetailDescriptionMetadata, 'WebColumnMovingEndEventArgsDetailDescriptionMetadata');
    WebColumnMovingEndEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEndEventArgsDetailDescriptionMetadata;
})();
